summaryrefslogtreecommitdiff
path: root/regress/lib/libc
diff options
context:
space:
mode:
Diffstat (limited to 'regress/lib/libc')
-rw-r--r--regress/lib/libc/basename/basename_test.c10
-rw-r--r--regress/lib/libc/db/dbtest.c13
-rw-r--r--regress/lib/libc/dirname/dirname_test.c10
-rw-r--r--regress/lib/libc/mkstemp/mkstemp_test.c5
-rw-r--r--regress/lib/libc/popen/popen.c4
-rw-r--r--regress/lib/libc/sys/macros.h6
-rw-r--r--regress/lib/libc/sys/t_access.c5
-rw-r--r--regress/lib/libc/sys/t_chroot.c5
-rw-r--r--regress/lib/libc/sys/t_clock_gettime.c8
-rw-r--r--regress/lib/libc/sys/t_dup.c5
-rw-r--r--regress/lib/libc/sys/t_fork.c11
-rw-r--r--regress/lib/libc/sys/t_fsync.c5
-rw-r--r--regress/lib/libc/sys/t_getgroups.c5
-rw-r--r--regress/lib/libc/sys/t_getitimer.c5
-rw-r--r--regress/lib/libc/sys/t_getlogin.c11
-rw-r--r--regress/lib/libc/sys/t_getpid.c5
-rw-r--r--regress/lib/libc/sys/t_getrusage.c5
-rw-r--r--regress/lib/libc/sys/t_getsid.c5
-rw-r--r--regress/lib/libc/sys/t_gettimeofday.c6
-rw-r--r--regress/lib/libc/sys/t_kevent.c5
-rw-r--r--regress/lib/libc/sys/t_kill.c5
-rw-r--r--regress/lib/libc/sys/t_link.c8
-rw-r--r--regress/lib/libc/sys/t_minherit.c7
-rw-r--r--regress/lib/libc/sys/t_mkdir.c7
-rw-r--r--regress/lib/libc/sys/t_mkfifo.c5
-rw-r--r--regress/lib/libc/sys/t_mknod.c5
-rw-r--r--regress/lib/libc/sys/t_mlock.c5
-rw-r--r--regress/lib/libc/sys/t_mmap.c7
-rw-r--r--regress/lib/libc/sys/t_msgctl.c5
-rw-r--r--regress/lib/libc/sys/t_msgget.c6
-rw-r--r--regress/lib/libc/sys/t_msgrcv.c5
-rw-r--r--regress/lib/libc/sys/t_msgsnd.c5
-rw-r--r--regress/lib/libc/sys/t_msync.c5
-rw-r--r--regress/lib/libc/sys/t_pipe.c8
-rw-r--r--regress/lib/libc/sys/t_pipe2.c5
-rw-r--r--regress/lib/libc/sys/t_ptrace.c7
-rw-r--r--regress/lib/libc/sys/t_revoke.c5
-rw-r--r--regress/lib/libc/sys/t_sendrecv.c5
-rw-r--r--regress/lib/libc/sys/t_setrlimit.c5
-rw-r--r--regress/lib/libc/sys/t_setuid.c5
-rw-r--r--regress/lib/libc/sys/t_sigaction.c7
-rw-r--r--regress/lib/libc/sys/t_sigaltstack.c5
-rw-r--r--regress/lib/libc/sys/t_socketpair.c5
-rw-r--r--regress/lib/libc/sys/t_stat.c5
-rw-r--r--regress/lib/libc/sys/t_syscall.c6
-rw-r--r--regress/lib/libc/sys/t_truncate.c5
-rw-r--r--regress/lib/libc/sys/t_umask.c5
-rw-r--r--regress/lib/libc/sys/t_unlink.c5
-rw-r--r--regress/lib/libc/sys/t_wait_noproc.c5
-rw-r--r--regress/lib/libc/sys/t_write.c7
50 files changed, 77 insertions, 227 deletions
diff --git a/regress/lib/libc/db/dbtest.c b/regress/lib/libc/db/dbtest.c
index b520d8db72d..a3375511b06 100644
--- a/regress/lib/libc/db/dbtest.c
+++ b/regress/lib/libc/db/dbtest.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: dbtest.c,v 1.18 2021/10/24 21:24:20 deraadt Exp $ */
+/* $OpenBSD: dbtest.c,v 1.19 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: dbtest.c,v 1.8 1996/05/03 21:57:48 cgd Exp $ */
/*-
@@ -30,7 +30,6 @@
* SUCH DAMAGE.
*/
-#include <sys/param.h>
#include <sys/stat.h>
#include <ctype.h>
@@ -45,6 +44,8 @@
#include <db.h>
+#define MINIMUM(a, b) (((a) < (b)) ? (a) : (b))
+
enum S { COMMAND, COMPARE, GET, PUT, REMOVE, SEQ, SEQFLAG, KEY, DATA };
void compare(DBT *, DBT *);
@@ -340,7 +341,7 @@ compare(db1, db2)
printf("compare failed: key->data len %lu != data len %lu\n",
db1->size, db2->size);
- len = MIN(db1->size, db2->size);
+ len = MINIMUM(db1->size, db2->size);
for (p1 = db1->data, p2 = db2->data; len--;)
if (*p1++ != *p2++) {
printf("compare failed at offset %ld\n",
@@ -371,7 +372,7 @@ get(dbp, kp)
(void)write(ofd, NOSUCHKEY, sizeof(NOSUCHKEY) - 1);
else
(void)fprintf(stderr, "%lu: %.*s: %s", lineno,
- MIN((int)kp->size, 20), kp->data, NOSUCHKEY);
+ MINIMUM((int)kp->size, 20), kp->data, NOSUCHKEY);
#undef NOSUCHKEY
break;
}
@@ -428,7 +429,7 @@ rem(dbp, kp)
(void)write(ofd, NOSUCHKEY, sizeof(NOSUCHKEY) - 1);
else if (flags != R_CURSOR)
(void)fprintf(stderr, "%lu: %.*s: %s", lineno,
- MIN((int)kp->size, 20), kp->data, NOSUCHKEY);
+ MINIMUM((int)kp->size, 20), kp->data, NOSUCHKEY);
else
(void)fprintf(stderr,
"%lu: rem of cursor failed\n", lineno);
@@ -472,7 +473,7 @@ seq(dbp, kp)
(void)write(ofd, NOSUCHKEY, sizeof(NOSUCHKEY) - 1);
else if (flags == R_CURSOR)
(void)fprintf(stderr, "%lu: %.*s: %s", lineno,
- MIN((int)kp->size, 20), kp->data, NOSUCHKEY);
+ MINIMUM((int)kp->size, 20), kp->data, NOSUCHKEY);
else
(void)fprintf(stderr,
"%lu: seq (%s) failed\n", lineno, sflags(flags));
diff --git a/regress/lib/libc/mkstemp/mkstemp_test.c b/regress/lib/libc/mkstemp/mkstemp_test.c
index c1c05eae39d..b92619cd360 100644
--- a/regress/lib/libc/mkstemp/mkstemp_test.c
+++ b/regress/lib/libc/mkstemp/mkstemp_test.c
@@ -8,7 +8,7 @@
* contain any X's
*/
-#include <sys/param.h>
+#include <sys/types.h>
#include <sys/mman.h>
#include <sys/stat.h>
@@ -17,6 +17,7 @@
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
+#include <limits.h>
#include <unistd.h>
#define MAX_TEMPLATE_LEN 10
@@ -110,7 +111,7 @@ int
main(void)
{
struct stat sb, fsb;
- char cwd[MAXPATHLEN + 1];
+ char cwd[PATH_MAX + 1];
char *p;
size_t clen;
int i;
diff --git a/regress/lib/libc/popen/popen.c b/regress/lib/libc/popen/popen.c
index 916cb71b037..2e081de5842 100644
--- a/regress/lib/libc/popen/popen.c
+++ b/regress/lib/libc/popen/popen.c
@@ -29,13 +29,13 @@
* POSSIBILITY OF SUCH DAMAGE.
*/
-#include <sys/param.h>
#include <err.h>
#include <errno.h>
#include <paths.h>
#include <stdio.h>
#include <stdlib.h>
+#include <limits.h>
#include <time.h>
#include <unistd.h>
@@ -47,7 +47,7 @@
int
main(int argc, char **argv)
{
- char *buffer, command[MAXPATHLEN];
+ char *buffer, command[PATH_MAX];
int index, in;
FILE *pipe;
diff --git a/regress/lib/libc/sys/macros.h b/regress/lib/libc/sys/macros.h
index ee7d77c31de..cb0789eb71c 100644
--- a/regress/lib/libc/sys/macros.h
+++ b/regress/lib/libc/sys/macros.h
@@ -1,7 +1,6 @@
-/* $OpenBSD: macros.h,v 1.4 2021/09/02 15:28:41 mbuhl Exp $ */
+/* $OpenBSD: macros.h,v 1.5 2021/12/13 16:56:48 deraadt Exp $ */
/* Public domain - Moritz Buhl */
-#include <sys/param.h>
#include <sys/socket.h>
#include <sys/stdint.h>
#include <sys/sysctl.h>
@@ -11,8 +10,7 @@
#include <string.h>
#include <stdio.h>
-#define __RCSID(str)
-#define __COPYRIGHT(str)
+#define nitems(_a) (sizeof((_a)) / sizeof((_a)[0]))
#define __arraycount(_a) nitems(_a)
#define __unreachable() atf_tc_fail("unreachable")
diff --git a/regress/lib/libc/sys/t_access.c b/regress/lib/libc/sys/t_access.c
index ed6410423b3..531b17c46e6 100644
--- a/regress/lib/libc/sys/t_access.c
+++ b/regress/lib/libc/sys/t_access.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_access.c,v 1.2 2019/11/22 15:59:53 bluhm Exp $ */
+/* $OpenBSD: t_access.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_access.c,v 1.3 2019/07/16 17:29:18 martin Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_access.c,v 1.3 2019/07/16 17:29:18 martin Exp $");
-
#include "atf-c.h"
#include <sys/stat.h>
diff --git a/regress/lib/libc/sys/t_chroot.c b/regress/lib/libc/sys/t_chroot.c
index b2bc16e49e2..fb65bacebd9 100644
--- a/regress/lib/libc/sys/t_chroot.c
+++ b/regress/lib/libc/sys/t_chroot.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_chroot.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_chroot.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_chroot.c,v 1.2 2017/01/10 22:36:29 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_chroot.c,v 1.2 2017/01/10 22:36:29 christos Exp $");
-
#include <sys/wait.h>
#include <sys/stat.h>
diff --git a/regress/lib/libc/sys/t_clock_gettime.c b/regress/lib/libc/sys/t_clock_gettime.c
index b75be63e4cd..11105d22403 100644
--- a/regress/lib/libc/sys/t_clock_gettime.c
+++ b/regress/lib/libc/sys/t_clock_gettime.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_clock_gettime.c,v 1.2 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_clock_gettime.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_clock_gettime.c,v 1.3 2017/01/13 21:30:41 christos Exp $ */
/*-
@@ -58,12 +58,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2008\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_clock_gettime.c,v 1.3 2017/01/13 21:30:41 christos Exp $");
-
-#include <sys/param.h>
#include <sys/sysctl.h>
diff --git a/regress/lib/libc/sys/t_dup.c b/regress/lib/libc/sys/t_dup.c
index c998c228b4c..b461a5f7c84 100644
--- a/regress/lib/libc/sys/t_dup.c
+++ b/regress/lib/libc/sys/t_dup.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_dup.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_dup.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_dup.c,v 1.9 2017/01/13 20:31:53 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_dup.c,v 1.9 2017/01/13 20:31:53 christos Exp $");
-
#include <sys/resource.h>
#include <sys/stat.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_fork.c b/regress/lib/libc/sys/t_fork.c
index 8fbc502d1f8..b55b557824e 100644
--- a/regress/lib/libc/sys/t_fork.c
+++ b/regress/lib/libc/sys/t_fork.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_fork.c,v 1.4 2021/09/28 05:39:24 anton Exp $ */
+/* $OpenBSD: t_fork.c,v 1.5 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_fork.c,v 1.4 2019/04/06 15:41:54 kamil Exp $ */
/*-
@@ -28,16 +28,11 @@
*/
#include "macros.h"
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2018, 2019\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_fork.c,v 1.4 2019/04/06 15:41:54 kamil Exp $");
-
-#include <sys/param.h>
+#include <sys/types.h>
+#include <sys/signal.h>
#ifdef __OpenBSD__
#include <sys/proc.h>
#endif
-#include <sys/types.h>
#include <sys/sysctl.h>
#include <sys/wait.h>
#include <sched.h>
diff --git a/regress/lib/libc/sys/t_fsync.c b/regress/lib/libc/sys/t_fsync.c
index bc3cd7939b9..66653df633d 100644
--- a/regress/lib/libc/sys/t_fsync.c
+++ b/regress/lib/libc/sys/t_fsync.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_fsync.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_fsync.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_fsync.c,v 1.2 2012/03/18 07:00:52 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_fsync.c,v 1.2 2012/03/18 07:00:52 jruoho Exp $");
-
#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
diff --git a/regress/lib/libc/sys/t_getgroups.c b/regress/lib/libc/sys/t_getgroups.c
index 5cecd3031fc..a17c9c67780 100644
--- a/regress/lib/libc/sys/t_getgroups.c
+++ b/regress/lib/libc/sys/t_getgroups.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getgroups.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_getgroups.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getgroups.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getgroups.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
#include <sys/wait.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_getitimer.c b/regress/lib/libc/sys/t_getitimer.c
index 9e5bd792ed7..b18bc75cd08 100644
--- a/regress/lib/libc/sys/t_getitimer.c
+++ b/regress/lib/libc/sys/t_getitimer.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getitimer.c,v 1.3 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_getitimer.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getitimer.c,v 1.3 2019/07/13 12:44:02 gson Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getitimer.c,v 1.3 2019/07/13 12:44:02 gson Exp $");
-
#include <sys/time.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_getlogin.c b/regress/lib/libc/sys/t_getlogin.c
index 01e5263850e..b4f06fdee63 100644
--- a/regress/lib/libc/sys/t_getlogin.c
+++ b/regress/lib/libc/sys/t_getlogin.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getlogin.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_getlogin.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getlogin.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,16 +32,13 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getlogin.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
-#include <sys/param.h>
#include <sys/wait.h>
#include "atf-c.h"
#include <errno.h>
#include <stdlib.h>
#include <string.h>
+#include <limits.h>
#include <unistd.h>
ATF_TC(getlogin_r_err);
@@ -65,7 +62,7 @@ ATF_TC_HEAD(getlogin_same, tc)
ATF_TC_BODY(getlogin_same, tc)
{
- char buf[MAXLOGNAME];
+ char buf[LOGIN_NAME_MAX];
char *str;
str = getlogin();
@@ -128,7 +125,7 @@ ATF_TC_HEAD(setlogin_err, tc)
ATF_TC_BODY(setlogin_err, tc)
{
- char buf[MAXLOGNAME + 1];
+ char buf[LOGIN_NAME_MAX + 1];
char *name;
pid_t pid;
int sta;
diff --git a/regress/lib/libc/sys/t_getpid.c b/regress/lib/libc/sys/t_getpid.c
index 56b6391e3e2..db9f8c87460 100644
--- a/regress/lib/libc/sys/t_getpid.c
+++ b/regress/lib/libc/sys/t_getpid.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getpid.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_getpid.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getpid.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getpid.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
#include <sys/wait.h>
#include <stdlib.h>
diff --git a/regress/lib/libc/sys/t_getrusage.c b/regress/lib/libc/sys/t_getrusage.c
index 316377f8ce8..1a9e3d139cd 100644
--- a/regress/lib/libc/sys/t_getrusage.c
+++ b/regress/lib/libc/sys/t_getrusage.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getrusage.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_getrusage.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getrusage.c,v 1.8 2018/05/09 08:45:03 mrg Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getrusage.c,v 1.8 2018/05/09 08:45:03 mrg Exp $");
-
#include <sys/resource.h>
#include <sys/time.h>
diff --git a/regress/lib/libc/sys/t_getsid.c b/regress/lib/libc/sys/t_getsid.c
index d9288dd8ed0..9bd82cd2baf 100644
--- a/regress/lib/libc/sys/t_getsid.c
+++ b/regress/lib/libc/sys/t_getsid.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_getsid.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_getsid.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_getsid.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_getsid.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
#include <sys/wait.h>
#include <errno.h>
diff --git a/regress/lib/libc/sys/t_gettimeofday.c b/regress/lib/libc/sys/t_gettimeofday.c
index 015204b1fc9..7a7d319be1c 100644
--- a/regress/lib/libc/sys/t_gettimeofday.c
+++ b/regress/lib/libc/sys/t_gettimeofday.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_gettimeofday.c,v 1.4 2021/09/27 14:07:44 mbuhl Exp $ */
+/* $OpenBSD: t_gettimeofday.c,v 1.5 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_gettimeofday.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,13 +32,11 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_gettimeofday.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
#include <sys/time.h>
#include "atf-c.h"
#include <errno.h>
+#include <signal.h>
#include <string.h>
#ifdef __OpenBSD__
diff --git a/regress/lib/libc/sys/t_kevent.c b/regress/lib/libc/sys/t_kevent.c
index 171e1f3dc99..917ab7f1dd6 100644
--- a/regress/lib/libc/sys/t_kevent.c
+++ b/regress/lib/libc/sys/t_kevent.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_kevent.c,v 1.1 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_kevent.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_kevent.c,v 1.9 2020/10/31 01:08:32 christos Exp $ */
/*-
@@ -31,9 +31,6 @@
*/
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_kevent.c,v 1.9 2020/10/31 01:08:32 christos Exp $");
-
#include <sys/types.h>
#include <sys/event.h>
diff --git a/regress/lib/libc/sys/t_kill.c b/regress/lib/libc/sys/t_kill.c
index bce0f2f111f..0c55dfa41b2 100644
--- a/regress/lib/libc/sys/t_kill.c
+++ b/regress/lib/libc/sys/t_kill.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_kill.c,v 1.3 2021/09/28 05:39:24 anton Exp $ */
+/* $OpenBSD: t_kill.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_kill.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_kill.c,v 1.1 2011/07/07 06:57:53 jruoho Exp $");
-
#include <sys/wait.h>
#include <errno.h>
diff --git a/regress/lib/libc/sys/t_link.c b/regress/lib/libc/sys/t_link.c
index 4a98b5b4098..12dbd8b595b 100644
--- a/regress/lib/libc/sys/t_link.c
+++ b/regress/lib/libc/sys/t_link.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_link.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_link.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_link.c,v 1.3 2017/01/13 20:42:36 christos Exp $ */
/*-
@@ -32,10 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_link.c,v 1.3 2017/01/13 20:42:36 christos Exp $");
-
-#include <sys/param.h>
#include <sys/stat.h>
#include "atf-c.h"
@@ -112,7 +108,7 @@ ATF_TC_HEAD(link_err, tc)
ATF_TC_BODY(link_err, tc)
{
- char buf[MAXPATHLEN + 1];
+ char buf[PATH_MAX + 1];
int fd;
(void)memset(buf, 'x', sizeof(buf));
diff --git a/regress/lib/libc/sys/t_minherit.c b/regress/lib/libc/sys/t_minherit.c
index dd9ddf1d1ed..578092352c6 100644
--- a/regress/lib/libc/sys/t_minherit.c
+++ b/regress/lib/libc/sys/t_minherit.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_minherit.c,v 1.1 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_minherit.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_minherit.c,v 1.1 2014/07/18 12:34:52 christos Exp $ */
/*-
@@ -31,10 +31,6 @@
*/
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_minherit.c,v 1.1 2014/07/18 12:34:52 christos Exp $");
-
-#include <sys/param.h>
#include <sys/mman.h>
#include <sys/sysctl.h>
#include <sys/wait.h>
@@ -43,6 +39,7 @@ __RCSID("$NetBSD: t_minherit.c,v 1.1 2014/07/18 12:34:52 christos Exp $");
#include <fcntl.h>
#include <stdlib.h>
#include <string.h>
+#include <signal.h>
#include <unistd.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_mkdir.c b/regress/lib/libc/sys/t_mkdir.c
index 490ed779141..5052bd39883 100644
--- a/regress/lib/libc/sys/t_mkdir.c
+++ b/regress/lib/libc/sys/t_mkdir.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_mkdir.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_mkdir.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_mkdir.c,v 1.2 2011/10/15 07:38:31 jruoho Exp $ */
/*-
@@ -32,11 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2008\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_mkdir.c,v 1.2 2011/10/15 07:38:31 jruoho Exp $");
-
#include <sys/stat.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_mkfifo.c b/regress/lib/libc/sys/t_mkfifo.c
index 01aff8de15a..13cd2d19227 100644
--- a/regress/lib/libc/sys/t_mkfifo.c
+++ b/regress/lib/libc/sys/t_mkfifo.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_mkfifo.c,v 1.1 2019/11/19 19:57:03 bluhm Exp $ */
+/* $OpenBSD: t_mkfifo.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_mkfifo.c,v 1.3 2019/06/20 03:31:54 kamil Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_mkfifo.c,v 1.3 2019/06/20 03:31:54 kamil Exp $");
-
#include <sys/stat.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_mknod.c b/regress/lib/libc/sys/t_mknod.c
index b1e412cb688..0c8b54f85fd 100644
--- a/regress/lib/libc/sys/t_mknod.c
+++ b/regress/lib/libc/sys/t_mknod.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_mknod.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_mknod.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_mknod.c,v 1.2 2012/03/18 07:00:52 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_mknod.c,v 1.2 2012/03/18 07:00:52 jruoho Exp $");
-
#include <sys/stat.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_mlock.c b/regress/lib/libc/sys/t_mlock.c
index e41f52443cb..865bd9e36ba 100644
--- a/regress/lib/libc/sys/t_mlock.c
+++ b/regress/lib/libc/sys/t_mlock.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_mlock.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_mlock.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_mlock.c,v 1.8 2020/01/24 08:45:16 skrll Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_mlock.c,v 1.8 2020/01/24 08:45:16 skrll Exp $");
-
#include <sys/mman.h>
#include <sys/resource.h>
#include <sys/sysctl.h>
diff --git a/regress/lib/libc/sys/t_mmap.c b/regress/lib/libc/sys/t_mmap.c
index 8d167cd5ec6..59c74296e39 100644
--- a/regress/lib/libc/sys/t_mmap.c
+++ b/regress/lib/libc/sys/t_mmap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_mmap.c,v 1.3 2020/12/06 18:46:07 bluhm Exp $ */
+/* $OpenBSD: t_mmap.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_mmap.c,v 1.14 2020/06/26 07:50:11 jruoho Exp $ */
/*-
@@ -58,10 +58,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_mmap.c,v 1.14 2020/06/26 07:50:11 jruoho Exp $");
-
-#include <sys/param.h>
#include <sys/disklabel.h>
#include <sys/mman.h>
#include <sys/stat.h>
@@ -75,6 +71,7 @@ __RCSID("$NetBSD: t_mmap.c,v 1.14 2020/06/26 07:50:11 jruoho Exp $");
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
+#include <limits.h>
#include <string.h>
#include <unistd.h>
#include <paths.h>
diff --git a/regress/lib/libc/sys/t_msgctl.c b/regress/lib/libc/sys/t_msgctl.c
index 3e267918d99..91c0eaaeafe 100644
--- a/regress/lib/libc/sys/t_msgctl.c
+++ b/regress/lib/libc/sys/t_msgctl.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_msgctl.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_msgctl.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_msgctl.c,v 1.7 2017/10/07 17:15:44 kre Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_msgctl.c,v 1.7 2017/10/07 17:15:44 kre Exp $");
-
#include <sys/msg.h>
#include <sys/stat.h>
#include <sys/sysctl.h>
diff --git a/regress/lib/libc/sys/t_msgget.c b/regress/lib/libc/sys/t_msgget.c
index c5b7d97e156..f4d3013b6fb 100644
--- a/regress/lib/libc/sys/t_msgget.c
+++ b/regress/lib/libc/sys/t_msgget.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_msgget.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_msgget.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_msgget.c,v 1.3 2017/10/08 08:31:05 kre Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_msgget.c,v 1.3 2017/10/08 08:31:05 kre Exp $");
-
#include <sys/msg.h>
#include <sys/stat.h>
#include <sys/sysctl.h>
@@ -45,6 +42,7 @@ __RCSID("$NetBSD: t_msgget.c,v 1.3 2017/10/08 08:31:05 kre Exp $");
#include <pwd.h>
#include <stdio.h>
#include <stdlib.h>
+#include <signal.h>
#include <string.h>
#include <sysexits.h>
#include <time.h>
diff --git a/regress/lib/libc/sys/t_msgrcv.c b/regress/lib/libc/sys/t_msgrcv.c
index 58dde4e1f2b..2e73b3d5baf 100644
--- a/regress/lib/libc/sys/t_msgrcv.c
+++ b/regress/lib/libc/sys/t_msgrcv.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_msgrcv.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_msgrcv.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_msgrcv.c,v 1.5 2017/10/08 08:31:05 kre Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_msgrcv.c,v 1.5 2017/10/08 08:31:05 kre Exp $");
-
#include <sys/msg.h>
#include <sys/stat.h>
#include <sys/sysctl.h>
diff --git a/regress/lib/libc/sys/t_msgsnd.c b/regress/lib/libc/sys/t_msgsnd.c
index 1130a74112c..4ea2aa485e5 100644
--- a/regress/lib/libc/sys/t_msgsnd.c
+++ b/regress/lib/libc/sys/t_msgsnd.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_msgsnd.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_msgsnd.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_msgsnd.c,v 1.4 2017/10/08 08:31:05 kre Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_msgsnd.c,v 1.4 2017/10/08 08:31:05 kre Exp $");
-
#include <sys/msg.h>
#include <sys/stat.h>
#include <sys/sysctl.h>
diff --git a/regress/lib/libc/sys/t_msync.c b/regress/lib/libc/sys/t_msync.c
index 2405199592f..acce0f664eb 100644
--- a/regress/lib/libc/sys/t_msync.c
+++ b/regress/lib/libc/sys/t_msync.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_msync.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_msync.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_msync.c,v 1.3 2017/01/14 20:52:42 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_msync.c,v 1.3 2017/01/14 20:52:42 christos Exp $");
-
#include <sys/mman.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_pipe.c b/regress/lib/libc/sys/t_pipe.c
index 2fcb6d4b131..7640cc2944e 100644
--- a/regress/lib/libc/sys/t_pipe.c
+++ b/regress/lib/libc/sys/t_pipe.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_pipe.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_pipe.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_pipe.c,v 1.7 2020/06/26 07:50:11 jruoho Exp $ */
/*-
@@ -29,12 +29,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2008\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_pipe.c,v 1.7 2020/06/26 07:50:11 jruoho Exp $");
-
#include <sys/types.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_pipe2.c b/regress/lib/libc/sys/t_pipe2.c
index 07991de4558..173d467c38e 100644
--- a/regress/lib/libc/sys/t_pipe2.c
+++ b/regress/lib/libc/sys/t_pipe2.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_pipe2.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_pipe2.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_pipe2.c,v 1.9 2017/01/13 21:19:45 christos Exp $ */
/*-
@@ -39,9 +39,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_pipe2.c,v 1.9 2017/01/13 21:19:45 christos Exp $");
-
#include "atf-c.h"
#include <fcntl.h>
#include <unistd.h>
diff --git a/regress/lib/libc/sys/t_ptrace.c b/regress/lib/libc/sys/t_ptrace.c
index a48616efb23..4b87acfdd28 100644
--- a/regress/lib/libc/sys/t_ptrace.c
+++ b/regress/lib/libc/sys/t_ptrace.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_ptrace.c,v 1.4 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_ptrace.c,v 1.5 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_ptrace.c,v 1.4 2018/05/14 12:44:40 kamil Exp $ */
/*-
@@ -29,16 +29,13 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_ptrace.c,v 1.4 2018/05/14 12:44:40 kamil Exp $");
-
-#include <sys/param.h>
#include <sys/types.h>
#include <sys/ptrace.h>
#include <sys/stat.h>
#include <sys/sysctl.h>
#include <err.h>
#include <errno.h>
+#include <limits.h>
#include <unistd.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_revoke.c b/regress/lib/libc/sys/t_revoke.c
index 7640c2d8713..d330b8832af 100644
--- a/regress/lib/libc/sys/t_revoke.c
+++ b/regress/lib/libc/sys/t_revoke.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_revoke.c,v 1.2 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_revoke.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_revoke.c,v 1.2 2017/01/13 21:15:57 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_revoke.c,v 1.2 2017/01/13 21:15:57 christos Exp $");
-
#include <sys/resource.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_sendrecv.c b/regress/lib/libc/sys/t_sendrecv.c
index 4b62505c284..ae6425f40dd 100644
--- a/regress/lib/libc/sys/t_sendrecv.c
+++ b/regress/lib/libc/sys/t_sendrecv.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_sendrecv.c,v 1.2 2021/05/31 16:56:27 bluhm Exp $ */
+/* $OpenBSD: t_sendrecv.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_sendrecv.c,v 1.8 2021/03/28 17:30:01 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_sendrecv.c,v 1.8 2021/03/28 17:30:01 christos Exp $");
-
#include "atf-c.h"
#include <sys/types.h>
#include <sys/socket.h>
diff --git a/regress/lib/libc/sys/t_setrlimit.c b/regress/lib/libc/sys/t_setrlimit.c
index d72ec5216d7..c9c64d42f01 100644
--- a/regress/lib/libc/sys/t_setrlimit.c
+++ b/regress/lib/libc/sys/t_setrlimit.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_setrlimit.c,v 1.1 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_setrlimit.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_setrlimit.c,v 1.7 2020/10/13 06:58:57 rin Exp $ */
/*-
@@ -31,9 +31,6 @@
*/
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_setrlimit.c,v 1.7 2020/10/13 06:58:57 rin Exp $");
-
#include <sys/resource.h>
#include <sys/mman.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_setuid.c b/regress/lib/libc/sys/t_setuid.c
index 5903635f06a..69240413907 100644
--- a/regress/lib/libc/sys/t_setuid.c
+++ b/regress/lib/libc/sys/t_setuid.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_setuid.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_setuid.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_setuid.c,v 1.1 2011/07/07 06:57:54 jruoho Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_setuid.c,v 1.1 2011/07/07 06:57:54 jruoho Exp $");
-
#include <sys/wait.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_sigaction.c b/regress/lib/libc/sys/t_sigaction.c
index 0451a8533e1..4254e1fece2 100644
--- a/regress/lib/libc/sys/t_sigaction.c
+++ b/regress/lib/libc/sys/t_sigaction.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_sigaction.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_sigaction.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_sigaction.c,v 1.5 2017/01/13 21:30:41 christos Exp $ */
/*-
@@ -29,11 +29,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2010\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_sigaction.c,v 1.5 2017/01/13 21:30:41 christos Exp $");
-
#include <sys/wait.h>
#include <signal.h>
diff --git a/regress/lib/libc/sys/t_sigaltstack.c b/regress/lib/libc/sys/t_sigaltstack.c
index ac02650296a..b02063bf2d9 100644
--- a/regress/lib/libc/sys/t_sigaltstack.c
+++ b/regress/lib/libc/sys/t_sigaltstack.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_sigaltstack.c,v 1.1 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_sigaltstack.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_sigaltstack.c,v 1.2 2020/05/01 21:35:30 christos Exp $ */
/*-
@@ -28,9 +28,6 @@
*/
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_sigaltstack.c,v 1.2 2020/05/01 21:35:30 christos Exp $");
-
#include <signal.h>
#include <stdbool.h>
diff --git a/regress/lib/libc/sys/t_socketpair.c b/regress/lib/libc/sys/t_socketpair.c
index c9f0b9ee545..e24a166161b 100644
--- a/regress/lib/libc/sys/t_socketpair.c
+++ b/regress/lib/libc/sys/t_socketpair.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_socketpair.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_socketpair.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_socketpair.c,v 1.2 2017/01/13 20:04:52 christos Exp $ */
/*-
@@ -39,9 +39,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_socketpair.c,v 1.2 2017/01/13 20:04:52 christos Exp $");
-
#include "atf-c.h"
#include <fcntl.h>
#include <unistd.h>
diff --git a/regress/lib/libc/sys/t_stat.c b/regress/lib/libc/sys/t_stat.c
index 5aadf39b997..eca93f83bd8 100644
--- a/regress/lib/libc/sys/t_stat.c
+++ b/regress/lib/libc/sys/t_stat.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_stat.c,v 1.3 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_stat.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_stat.c,v 1.6 2019/07/16 17:29:18 martin Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_stat.c,v 1.6 2019/07/16 17:29:18 martin Exp $");
-
#include <sys/stat.h>
#include <sys/socket.h>
#include <sys/types.h>
diff --git a/regress/lib/libc/sys/t_syscall.c b/regress/lib/libc/sys/t_syscall.c
index 454905837fa..a8e3cd12881 100644
--- a/regress/lib/libc/sys/t_syscall.c
+++ b/regress/lib/libc/sys/t_syscall.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_syscall.c,v 1.3 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_syscall.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_syscall.c,v 1.4 2021/01/18 05:44:20 simonb Exp $ */
/*-
@@ -32,10 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_syscall.c,v 1.4 2021/01/18 05:44:20 simonb Exp $");
-
-
#include "atf-c.h"
#include <stdio.h>
#include <unistd.h>
diff --git a/regress/lib/libc/sys/t_truncate.c b/regress/lib/libc/sys/t_truncate.c
index 7d3dedb7b88..f952efc35e8 100644
--- a/regress/lib/libc/sys/t_truncate.c
+++ b/regress/lib/libc/sys/t_truncate.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_truncate.c,v 1.2 2021/10/24 21:24:20 deraadt Exp $ */
+/* $OpenBSD: t_truncate.c,v 1.3 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_truncate.c,v 1.3 2017/01/13 20:03:51 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_truncate.c,v 1.3 2017/01/13 20:03:51 christos Exp $");
-
#include <sys/stat.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_umask.c b/regress/lib/libc/sys/t_umask.c
index 717ed1ac746..53837b654e7 100644
--- a/regress/lib/libc/sys/t_umask.c
+++ b/regress/lib/libc/sys/t_umask.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_umask.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_umask.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_umask.c,v 1.2 2017/01/13 19:34:19 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_umask.c,v 1.2 2017/01/13 19:34:19 christos Exp $");
-
#include <sys/stat.h>
#include <sys/wait.h>
diff --git a/regress/lib/libc/sys/t_unlink.c b/regress/lib/libc/sys/t_unlink.c
index 516e2dca064..2b1170ead7d 100644
--- a/regress/lib/libc/sys/t_unlink.c
+++ b/regress/lib/libc/sys/t_unlink.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_unlink.c,v 1.1 2019/11/19 19:57:04 bluhm Exp $ */
+/* $OpenBSD: t_unlink.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_unlink.c,v 1.4 2017/01/14 20:55:26 christos Exp $ */
/*-
@@ -32,9 +32,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_unlink.c,v 1.4 2017/01/14 20:55:26 christos Exp $");
-
#include <sys/stat.h>
#include "atf-c.h"
diff --git a/regress/lib/libc/sys/t_wait_noproc.c b/regress/lib/libc/sys/t_wait_noproc.c
index 73fc7ae0352..ee3454eb709 100644
--- a/regress/lib/libc/sys/t_wait_noproc.c
+++ b/regress/lib/libc/sys/t_wait_noproc.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_wait_noproc.c,v 1.1 2021/09/02 12:40:44 mbuhl Exp $ */
+/* $OpenBSD: t_wait_noproc.c,v 1.2 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_wait_noproc.c,v 1.5 2016/11/09 17:50:19 kamil Exp $ */
/*-
@@ -29,9 +29,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__RCSID("$NetBSD: t_wait_noproc.c,v 1.5 2016/11/09 17:50:19 kamil Exp $");
-
#include <sys/wait.h>
#include <sys/resource.h>
diff --git a/regress/lib/libc/sys/t_write.c b/regress/lib/libc/sys/t_write.c
index 326032db712..8d01ebfba88 100644
--- a/regress/lib/libc/sys/t_write.c
+++ b/regress/lib/libc/sys/t_write.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: t_write.c,v 1.3 2020/11/09 23:18:51 bluhm Exp $ */
+/* $OpenBSD: t_write.c,v 1.4 2021/12/13 16:56:48 deraadt Exp $ */
/* $NetBSD: t_write.c,v 1.7 2019/07/16 17:29:18 martin Exp $ */
/*-
@@ -29,11 +29,6 @@
#include "macros.h"
-#include <sys/cdefs.h>
-__COPYRIGHT("@(#) Copyright (c) 2008\
- The NetBSD Foundation, inc. All rights reserved.");
-__RCSID("$NetBSD: t_write.c,v 1.7 2019/07/16 17:29:18 martin Exp $");
-
#include <sys/uio.h>
#include <sys/mman.h>
diff --git a/regress/lib/libc/basename/basename_test.c b/regress/lib/libc/basename/basename_test.c
index 34e138c726e..7272c46b1dc 100644
--- a/regress/lib/libc/basename/basename_test.c
+++ b/regress/lib/libc/basename/basename_test.c
@@ -4,8 +4,6 @@
* Public domain.
*/
-#include <sys/param.h>
-
#include <libgen.h>
#include <stdio.h>
#include <string.h>
@@ -15,7 +13,7 @@
int
main(void)
{
- char path[2 * MAXPATHLEN];
+ char path[2 * PATH_MAX];
const char *dir = "junk/";
const char *fname = "file.name.ext";
char *str;
@@ -35,7 +33,7 @@ main(void)
* 1) path is NULL
* 2) path is the empty string
* 3) path is composed entirely of slashes
* 4) the resulting name is larger than MAXPATHLEN
*
* The first two cases require that a pointer
* to the string "." be returned.
@@ -58,7 +56,7 @@ main(void)
goto fail;
/* Case 3 */
- for (i = 0; i < MAXPATHLEN - 1; i++)
+ for (i = 0; i < PATH_MAX - 1; i++)
strlcat(path, "/", sizeof(path)); /* path cleared above */
str = basename(path);
if (strcmp(str, "/") != 0)
@@ -67,7 +65,7 @@ main(void)
/* Case 4 */
strlcpy(path, "/", sizeof(path));
strlcat(path, dir, sizeof(path));
- for (i = 0; i <= MAXPATHLEN; i += sizeof(fname))
+ for (i = 0; i <= PATH_MAX; i += sizeof(fname))
strlcat(path, fname, sizeof(path));
str = basename(path);
if (str != NULL || errno != ENAMETOOLONG)
@@ -35,7 +33,7 @@ main(void)
* 2) path is the empty string
* 3) path is composed entirely of slashes
- * 4) the resulting name is larger than MAXPATHLEN
+ * 4) the resulting name is larger than PATH_MAX
*
* The first two cases require that a pointer
diff --git a/regress/lib/libc/dirname/dirname_test.c b/regress/lib/libc/dirname/dirname_test.c
index 27d32b6edaf..250b4def667 100644
--- a/regress/lib/libc/dirname/dirname_test.c
+++ b/regress/lib/libc/dirname/dirname_test.c
@@ -4,8 +4,6 @@
* Public domain.
*/
-#include <sys/param.h>
-
#include <libgen.h>
#include <stdio.h>
#include <string.h>
@@ -16,7 +14,7 @@
int
main(void)
{
- char path[2 * MAXPATHLEN];
+ char path[2 * PATH_MAX];
char dname[128];
const char *dir = "junk";
const char *fname = "/file.name.ext";
@@ -39,7 +37,7 @@ main(void)
* 1) path is NULL
* 2) path is the empty string
* 3) path is composed entirely of slashes
* 4) the resulting name is larger than MAXPATHLEN
*
* The first two cases require that a pointer
* to the string "." be returned.
@@ -62,7 +60,7 @@ main(void)
errx(1, "2: dirname(%s) = %s != .", path, str);
/* Case 3 */
- for (i = 0; i < MAXPATHLEN - 1; i++)
+ for (i = 0; i < PATH_MAX - 1; i++)
strlcat(path, "/", sizeof(path)); /* path cleared above */
str = dirname(path);
if (strcmp(str, "/") != 0)
@@ -70,7 +68,7 @@ main(void)
/* Case 4 */
strlcpy(path, "/", sizeof(path)); /* reset path */
- for (i = 0; i <= MAXPATHLEN; i += strlen(dir))
+ for (i = 0; i <= PATH_MAX; i += strlen(dir))
strlcat(path, dir, sizeof(path));
strlcat(path, fname, sizeof(path));
str = dirname(path);
@@ -39,7 +37,7 @@ main(void)
* 2) path is the empty string
* 3) path is composed entirely of slashes
- * 4) the resulting name is larger than MAXPATHLEN
+ * 4) the resulting name is larger than PATH_MAX
*
* The first two cases require that a pointer